@@ -43,3 +43,16 @@ func (env *environment) getPlatform() string {
 	p, _, _, _ := host.PlatformInformation()
 	return p
 }
+
+func (env *environment) getCachePath() string {
+	defer env.tracer.trace(time.Now(), "getCachePath")
+	// get XDG_CACHE_HOME if present
+	if cachePath := returnOrBuildCachePath(env.getenv("XDG_CACHE_HOME")); len(cachePath) != 0 {
+		return cachePath
+	}
+	// HOME cache folder
+	if cachePath := returnOrBuildCachePath(env.homeDir() + "/.cache"); len(cachePath) != 0 {
+		return cachePath
+	}
+	return env.homeDir()
+}
